@@ -93,7 +93,7 @@ string AmovaCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-AmovaCommand::AmovaCommand(string option) {
+AmovaCommand::AmovaCommand(string option) : Command() {
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -154,6 +154,8 @@ int AmovaCommand::execute(){
 		
 		//read design file
 		designMap = new DesignMap(designFileName);
+        
+        if (m->getControl_pressed()) { delete designMap; return 0; }
 
 		if (outputdir == "") { outputdir = util.hasPath(phylipFileName); }
 						
