@@ -17,8 +17,7 @@ class AmovaCommand : public Command {
 	
 public:
 	AmovaCommand(string);
-	AmovaCommand();
-	~AmovaCommand() {}
+	~AmovaCommand() = default;
 	
 	vector<string> setParameters();
 	string getCommandName()			{ return "amova";					}
@@ -42,7 +41,7 @@ private:
 	bool abort;
 	vector<string> outputNames, Sets;
 
-	string outputDir, inputDir, designFileName, phylipFileName;
+	string inputDir, designFileName, phylipFileName;
 	DesignMap* designMap;
 	vector< vector<double> > distanceMatrix;
 	int iters;
