@@ -8,10 +8,12 @@
  */
 
 #include "chimeraperseuscommand.h"
-#include "deconvolutecommand.h"
+#include "uniqueseqscommand.h"
 #include "sequence.hpp"
 #include "counttable.h"
 #include "sequencecountparser.h"
+#include "removeseqscommand.h"
+
 //**********************************************************************************************************************
 vector<string> ChimeraPerseusCommand::setParameters(){	
 	try {
@@ -21,7 +23,7 @@ vector<string> ChimeraPerseusCommand::setParameters(){
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
         CommandParameter pdups("dereplicate", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(pdups);
-
+        CommandParameter premovechimeras("removechimeras", "Boolean", "", "t", "", "", "","fasta",false,false); parameters.push_back(premovechimeras);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
@@ -35,6 +37,7 @@ vector<string> ChimeraPerseusCommand::setParameters(){
         outputTypes["chimera"] = tempOutNames;
         outputTypes["accnos"] = tempOutNames;
         outputTypes["count"] = tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
 			
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -57,6 +60,7 @@ string ChimeraPerseusCommand::getHelpString(){
 		helpString += "The group parameter allows you to provide a group file.  When checking sequences, only sequences from the same group as the query sequence will be used as the reference. \n";
 		helpString += "The processors parameter allows you to specify how many processors you would like to use.  The default is 1. \n";
         helpString += "If the dereplicate parameter is false, then if one group finds the seqeunce to be chimeric, then all groups find it to be chimeric, default=f.\n";
+        helpString += "The removechimeras parameter allows you to indicate you would like to automatically remove the sequences that are flagged as chimeric. Default=t.\n";
 		helpString += "The alpha parameter ....  The default is -5.54. \n";
 		helpString += "The beta parameter ....  The default is 0.33. \n";
 		helpString += "The cutoff parameter ....  The default is 0.50. \n";
@@ -78,7 +82,8 @@ string ChimeraPerseusCommand::getOutputPattern(string type) {
         
         if (type == "chimera") {  pattern = "[filename],perseus.chimeras"; } 
         else if (type == "accnos") {  pattern = "[filename],perseus.accnos"; }
-        else if (type == "count") {  pattern = "[filename],perseus.pick.count_table"; }
+        else if (type == "fasta") {  pattern = "[filename],perseus.fasta"; }
+        else if (type == "count") {  pattern = "[filename],perseus.count_table"; }
         else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
@@ -89,7 +94,7 @@ string ChimeraPerseusCommand::getOutputPattern(string type) {
     }
 }
 //***************************************************************************************************************
-ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
+ChimeraPerseusCommand::ChimeraPerseusCommand(string option) : Command()  {
 	try {
         hasCount = false;
 		
@@ -157,13 +162,16 @@ ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
 			temp = validParameter.valid(parameters, "alpha");	if (temp == "not found"){	temp = "-5.54";	}
 			util.mothurConvert(temp, alpha);
 			
-			temp = validParameter.valid(parameters, "cutoff");	if (temp == "not found"){	temp = "0.33";	}
+			temp = validParameter.valid(parameters, "beta");	if (temp == "not found"){	temp = "0.33";	}
 			util.mothurConvert(temp, beta);
             
 			temp = validParameter.valid(parameters, "dereplicate");	
 			if (temp == "not found") { temp = "false";			}
 			dups = util.isTrue(temp);
             
+            temp = validParameter.valid(parameters, "removechimeras");            if (temp == "not found") { temp = "t"; }
+            removeChimeras = util.isTrue(temp);
+            
             if (!abort) {
                 if ((namefile != "") || (groupfile != "")) { //convert to count
                     
@@ -355,7 +363,7 @@ int ChimeraPerseusCommand::execute(){
         
         m->mothurOut("Checking sequences from " + fastafile + " ...\n" );
         
-        long start = time(NULL);
+        long start = time(nullptr);
         if (outputdir == "") { outputdir = util.hasPath(fastafile);  }
         map<string, string> variables;
         variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
@@ -385,7 +393,6 @@ int ChimeraPerseusCommand::execute(){
                     current->setMothurCalling(false);
                     groups = cparser.getNamesOfGroups();
                     group2Files = cparser.getFiles();
-                    
                 }
                 
                 if (m->getControl_pressed()) { return 0; }
@@ -406,12 +413,11 @@ int ChimeraPerseusCommand::execute(){
                     CountTable newCount; newCount.readTable(countfile, true, false);
                     
                     if (!util.isBlank(countlist)) {
-                        ifstream in2;
-                        util.openInputFile(countlist, in2);
+                        ifstream in2; util.openInputFile(countlist, in2);
                         
                         string name, group;
                         while (!in2.eof()) {
-                            in2 >> name; util.gobble(in2); in2 >> group; util.gobble(in2);
+                            in2 >> name; gobble(in2); in2 >> group; gobble(in2);
                             newCount.setAbund(name, group, 0);
                         }
                         in2.close();
@@ -422,12 +428,12 @@ int ChimeraPerseusCommand::execute(){
                     vector<string> namesInTable = newCount.printTable(newCountFile);  //returns non zeroed names
                     outputNames.push_back(newCountFile); outputTypes["count"].push_back(newCountFile);
                     
-                    set<string> doNotRemove = util.mothurConvert(namesInTable);
+                    unordered_set<string> doNotRemove = util.mothurConvert(namesInTable);
                    
                     //remove names we want to keep from accnos file.
-                    set<string> accnosNames = util.readAccnos(accnosFileName);
+                    unordered_set<string> accnosNames = util.readAccnos(accnosFileName);
                     ofstream out2; util.openOutputFile(accnosFileName, out2);
-                    for (set<string>::iterator it = accnosNames.begin(); it != accnosNames.end(); it++) { if (doNotRemove.count(*it) == 0) {  out2 << (*it) << endl; } }
+                    for (auto it = accnosNames.begin(); it != accnosNames.end(); it++) { if (doNotRemove.count(*it) == 0) {  out2 << (*it) << endl; } }
                     out2.close();
                 }
                 
@@ -455,10 +461,52 @@ int ChimeraPerseusCommand::execute(){
         
         if (m->getControl_pressed()) { for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
         
-        m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to check " + toString(numSeqs) + " sequences. " + toString(numChimeras) + " chimeras were found.\n");
+        m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to check " + toString(numSeqs) + " sequences. " + toString(numChimeras) + " chimeras were found.\n");
         outputNames.push_back(outputFileName); outputTypes["chimera"].push_back(outputFileName);
         outputNames.push_back(accnosFileName); outputTypes["accnos"].push_back(accnosFileName);
         
+        if (removeChimeras) {
+            if (!util.isBlank(accnosFileName)) {
+                m->mothurOut("\nRemoving chimeras from your input files:\n");
+                
+                string inputString = "fasta=" + fastafile + ", accnos=" + accnosFileName;
+                if ((countfile != "") && (!dups))   {   inputString += ", count=" + countfile;  }
+                
+                m->mothurOut("/******************************************/\n");
+                m->mothurOut("Running command: remove.seqs(" + inputString + ")\n");
+                current->setMothurCalling(true);
+                
+                Command* removeCommand = new RemoveSeqsCommand(inputString);
+                removeCommand->execute();
+                
+                map<string, vector<string> > filenames = removeCommand->getOutputFiles();
+                
+                delete removeCommand;
+                current->setMothurCalling(false);
+                m->mothurOut("/******************************************/\n");
+
+                if (countfile != "") {
+                    if (!dups) { //dereplicate=f, so remove sequences where any sample found the reads to be chimeric
+                        map<string, string> variables;
+                        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
+                        string currentName = getOutputFileName("count", variables);
+
+                        util.renameFile(filenames["count"][0], currentName);
+                        util.mothurRemove(filenames["count"][0]);
+                        outputNames.push_back(currentName); outputTypes["count"].push_back(currentName);
+                    }//else, mothur created a modified count file removing chimeras by sample. No need to include count file on remove.seqs command. Deconvolute function created modified count table already
+                }
+                
+                map<string, string> variables;
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
+                string currentName = getOutputFileName("fasta", variables);
+
+                util.renameFile(filenames["fasta"][0], currentName);
+                util.mothurRemove(filenames["fasta"][0]);
+                
+                outputNames.push_back(currentName); outputTypes["fasta"].push_back(currentName);
+            }else { m->mothurOut("\nNo chimeras found, skipping remove.seqs.\n"); }
+        }
         
 		//set accnos file as new current accnosfile
 		string currentName = "";
@@ -472,6 +520,11 @@ int ChimeraPerseusCommand::execute(){
 			if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setCountFile(currentName); }
 		}
 		
+        itTypes = outputTypes.find("fasta");
+        if (itTypes != outputTypes.end()) {
+            if ((itTypes->second).size() != 0) { currentName = (itTypes->second)[0]; current->setFastaFile(currentName); }
+        }
+        
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}	
 		m->mothurOutEndLine();
@@ -497,7 +550,7 @@ string ChimeraPerseusCommand::getCountFile(string& inputFile){
 		m->mothurOut("Running command: unique.seqs(" + inputString + ")\n");
 		current->setMothurCalling(true);
         
-		Command* uniqueCommand = new DeconvoluteCommand(inputString);
+		Command* uniqueCommand = new UniqueSeqsCommand(inputString);
 		uniqueCommand->execute();
 		
 		map<string, vector<string> > filenames = uniqueCommand->getOutputFiles();
@@ -558,15 +611,14 @@ vector<seqData> loadSequences(map<string, int>& nameMap, string thisGroupsFastaF
         bool error = false;
         vector<seqData> sequences;
         
-        ifstream in;
-        params->util.openInputFile(thisGroupsFastaFile, in);
+        ifstream in; params->util.openInputFile(thisGroupsFastaFile, in);
         
         vector<seqPriorityNode> nameVector;
         map<string, int>::iterator itNameMap;
         while (!in.eof()) {
             if (params->m->getControl_pressed()) { break; }
             
-            Sequence seq(in); params->util.gobble(in);
+            Sequence seq(in); gobble(in);
             
             itNameMap = nameMap.find(seq.getName());
             
@@ -609,7 +661,7 @@ void driverGroups(perseusGroupsData* params){
         if (params->hasCount && params->dups) { params->util.openOutputFile(params->countlist, outCountList); }
 		
         for (map<string, vector<string> >::iterator it = params->parsedFiles.begin(); it != params->parsedFiles.end(); it++) {
-            long start = time(NULL);	 if (params->m->getControl_pressed()) {  break; }
+            long start = time(nullptr);	 if (params->m->getControl_pressed()) {  break; }
             
             
             string thisGroup = it->first;
@@ -640,7 +692,7 @@ void driverGroups(perseusGroupsData* params){
                     string name;
                     if (params->hasCount) {
                         while (!in.eof()) {
-                            in >> name; params->util.gobble(in);
+                            in >> name; gobble(in);
                             outCountList << name << '\t' << thisGroup << endl;
                         }
                         in.close();
@@ -652,7 +704,7 @@ void driverGroups(perseusGroupsData* params){
 			params->util.appendFiles(driverParams->chimeraFileName, params->chimeraFileName); params->util.mothurRemove(driverParams->chimeraFileName);
 			params->util.appendFiles(driverParams->accnosFileName, params->accnosFileName); params->util.mothurRemove(driverParams->accnosFileName);
 			
-			params->m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to check " + toString(driverParams->count) + " sequences from group " + thisGroup + ".\n");
+			params->m->mothurOut("\nIt took " + toString(time(nullptr) - start) + " secs to check " + toString(driverParams->count) + " sequences from group " + thisGroup + ".\n");
             delete driverParams;
 		}	
 		
@@ -674,15 +726,14 @@ vector<seqData> ChimeraPerseusCommand::readFiles(string inputFile, map<string, i
 		//read fasta file and create sequenceData structure - checking for file mismatches
 		vector<seqData> sequences;
 		bool error = false;
-		ifstream in;
-		util.openInputFile(inputFile, in);
+		ifstream in; util.openInputFile(inputFile, in);
 		alignLength = 0;
         
 		while (!in.eof()) {
 			
 			if (m->getControl_pressed()) { in.close(); return sequences; }
 			
-			Sequence temp(in); util.gobble(in);
+			Sequence temp(in); gobble(in);
 			
 			it = nameMap.find(temp.getName());
 			if (it == nameMap.end()) { error = true; m->mothurOut("[ERROR]: " + temp.getName() + " is in your fasta file and not in your namefile, please correct.\n");  }
@@ -808,15 +859,12 @@ int ChimeraPerseusCommand::deconvoluteResults(string outputFileName, string accn
 	try {
         int total = 0;
 		
-        set<string> chimerasInFile = util.readAccnos(accnosFileName);//this is so if a sequence is found to be chimera in several samples we dont write it to the results file more than once
+        unordered_set<string> chimerasInFile = util.readAccnos(accnosFileName);//this is so if a sequence is found to be chimera in several samples we dont write it to the results file more than once
         util.printAccnos(accnosFileName, chimerasInFile);
     
 		//edit chimera file
-		ifstream in; 
-		util.openInputFile(outputFileName, in);
-		
-		ofstream out;
-		util.openOutputFile(outputFileName+".temp", out); out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
+		ifstream in;  util.openInputFile(outputFileName, in);
+		ofstream out; util.openOutputFile(outputFileName+".temp", out); out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
 		
 		int DiffsToBestMatch, BestMatchIndex, DiffstToChimera, IndexofLeftParent, IndexOfRightParent;
 		float temp1,temp2, temp3, temp4, temp5, temp6, temp7, temp8;
@@ -834,7 +882,7 @@ int ChimeraPerseusCommand::deconvoluteResults(string outputFileName, string accn
 		 */
 		
 		//get and print headers
-		BestMatchName = util.getline(in); util.gobble(in);
+		BestMatchName = util.getline(in); gobble(in);
 		out << BestMatchName << endl;
 		
 		while (!in.eof()) {
@@ -842,28 +890,28 @@ int ChimeraPerseusCommand::deconvoluteResults(string outputFileName, string accn
 			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove((outputFileName+".temp")); return 0; }
 			
 			bool print = false;
-			in >> index;	util.gobble(in);
+			in >> index;	gobble(in);
 			
 			if (index != "SequenceIndex") { //if you are not a header line, there will be a header line for each group if group file is given
-				in >> name;		util.gobble(in);
-				in >> DiffsToBestMatch; util.gobble(in);
-				in >> BestMatchIndex; util.gobble(in);
-				in >> BestMatchName; util.gobble(in);
-				in >> DiffstToChimera; util.gobble(in);
-				in >> IndexofLeftParent; util.gobble(in);
-				in >> IndexOfRightParent; util.gobble(in);
-				in >> parent1;	util.gobble(in);
-				in >> parent2;	util.gobble(in);
-				in >> temp1 >> temp2 >> temp3 >> temp4 >> temp5 >> temp6 >> temp7 >> temp8 >> flag; util.gobble(in);
+				in >> name;		gobble(in);
+				in >> DiffsToBestMatch; gobble(in);
+				in >> BestMatchIndex; gobble(in);
+				in >> BestMatchName; gobble(in);
+				in >> DiffstToChimera; gobble(in);
+				in >> IndexofLeftParent; gobble(in);
+				in >> IndexOfRightParent; gobble(in);
+				in >> parent1;	gobble(in);
+				in >> parent2;	gobble(in);
+				in >> temp1 >> temp2 >> temp3 >> temp4 >> temp5 >> temp6 >> temp7 >> temp8 >> flag; gobble(in);
 				
 				
                 //is this name already in the file
-                set<string>::iterator itNames = namesInFile.find((name));
+                auto itNames = namesInFile.find((name));
                 
                 if (itNames == namesInFile.end()) { //no not in file
                     if (flag == "good") { //are you really a no??
                         //is this sequence really not chimeric??
-                        set<string>::iterator itChimeras = chimerasInFile.find(name);
+                        auto itChimeras = chimerasInFile.find(name);
                         
                         //then you really are a no so print, otherwise skip
                         if (itChimeras == chimerasInFile.end()) { print = true; }
@@ -876,7 +924,7 @@ int ChimeraPerseusCommand::deconvoluteResults(string outputFileName, string accn
 					out << BestMatchName << '\t' << DiffstToChimera << '\t' << IndexofLeftParent << '\t' << IndexOfRightParent << '\t' << parent1 << '\t' << parent2 << '\t';
 					out << temp1 << '\t' << temp2 << '\t' << temp3 << '\t' << temp4 << '\t' << temp5 << '\t' << temp6 << '\t' << temp7 << '\t' << temp8 << '\t' << flag << endl;	
 				}
-			}else { index = util.getline(in); util.gobble(in); }
+			}else { index = util.getline(in); gobble(in); }
 		}
 		in.close();
 		out.close();
