@@ -22,7 +22,6 @@ class CooccurrenceCommand : public Command {
 public:
 	
 	CooccurrenceCommand(string);	
-	CooccurrenceCommand();
 	~CooccurrenceCommand(){}
 	
 	vector<string> setParameters();
@@ -39,7 +38,7 @@ public:
 	
 	
 private:
-    string metric, matrix, outputDir;
+    string metric, matrix;
     string label, sharedfile, groups;
     bool abort, allLines;
     set<string> labels;
