@@ -63,7 +63,7 @@ string DeuniqueTreeCommand::getOutputPattern(string type) {
     }
 }
 /***********************************************************/
-DeuniqueTreeCommand::DeuniqueTreeCommand(string option)  {
+DeuniqueTreeCommand::DeuniqueTreeCommand(string option) : Command()  {
 	try {
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
