@@ -88,7 +88,7 @@ string FilterSharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-FilterSharedCommand::FilterSharedCommand(string option) {
+FilterSharedCommand::FilterSharedCommand(string option) : Command() {
 	try {
 		allLines = true;
 		
@@ -209,7 +209,7 @@ int FilterSharedCommand::execute(){
         SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         Groups = lookup->getNamesGroups();
 		
-        while (lookup != NULL) {
+        while (lookup != nullptr) {
             
             if (m->getControl_pressed()) { delete lookup; break; }
             
