@@ -48,7 +48,7 @@ string GetlabelCommand::getHelpString(){
 }
 //**********************************************************************************************************************
 
-GetlabelCommand::GetlabelCommand(string option)  {
+GetlabelCommand::GetlabelCommand(string option) : Command()  {
 	try {
     
 		//allow user to run help
@@ -115,7 +115,7 @@ int GetlabelCommand::execute(){
 		OrderVector* order = input->getOrderVector();
 		string label = order->getLabel();
 		
-		while (order != NULL) {
+		while (order != nullptr) {
 			
 			if (m->getControl_pressed()) { delete input;  delete order; return 0; }
 			
