@@ -91,7 +91,7 @@ string GetLineageCommand::getOutputPattern(string type) {
         else if (type == "count")           {   pattern = "[filename],pick,[extension]";    }
         else if (type == "list")            {   pattern = "[filename],[distance],pick,[extension]";    }
         else if (type == "shared")          {   pattern = "[filename],[distance],pick,[extension]";    }
-        else if (type == "alignreport")     {   pattern = "[filename],pick.align.report";    }
+        else if (type == "alignreport")     {   pattern = "[filename],pick.[extension]";    }
         else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
@@ -102,7 +102,7 @@ string GetLineageCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetLineageCommand::GetLineageCommand(string option)  {
+GetLineageCommand::GetLineageCommand(string option) : Command()  {
 	try {
         if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -113,9 +113,6 @@ GetLineageCommand::GetLineageCommand(string option)  {
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			
-			
-			//check for required parameters			
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not open") { fastafile = ""; abort = true; }
 			else if (fastafile == "not found") {  fastafile = "";  }
@@ -210,13 +207,6 @@ GetLineageCommand::GetLineageCommand(string option)  {
                 label = validParameter.valid(parameters, "label");
                 if (label == "not found") { label = ""; m->mothurOut("[WARNING]: You did not provide a label, I will use the first label in your inputfile.\n");  }
             }
-            
-            if (countfile == "") {
-                if ((namefile == "") && ((fastafile != "") || (taxfile != ""))){
-                    vector<string> files; files.push_back(fastafile); files.push_back(taxfile);
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
 		}
 
 	}
@@ -438,12 +428,8 @@ string GetLineageCommand::readTax(){
 		string outputFileName = getOutputFileName("taxonomy", variables);
         string accnosFileName = outputFileName + ".accnos";
 		
-        ofstream out, outAccnos;
-		util.openOutputFile(outputFileName, out);
-        util.openOutputFile(accnosFileName, outAccnos);
-		
-		ifstream in;
-		util.openInputFile(taxfile, in);
+        ofstream out, outAccnos; util.openOutputFile(outputFileName, out); util.openOutputFile(accnosFileName, outAccnos);
+		ifstream in; util.openInputFile(taxfile, in);
 		string name, tax;
 		
 		bool wroteSomething = false;
@@ -460,8 +446,8 @@ string GetLineageCommand::readTax(){
 
 			if (m->getControl_pressed()) { break; }
 
-            in >> name; util.gobble(in);
-            tax = util.getline(in); util.gobble(in);
+            in >> name; gobble(in);
+            tax = util.getline(in); gobble(in);
             
             Taxonomy thisSeq(name, tax);
 			vector<Taxon> otuTax = thisSeq.getTaxons();
@@ -502,8 +488,7 @@ string GetLineageCommand::readConsTax(){
 		util.openOutputFile(outputFileName, out);
         util.openOutputFile(accnosFileName, outAccnos);
 		
-		ifstream in;
-		util.openInputFile(constaxonomy, in);
+		ifstream in; util.openInputFile(constaxonomy, in);
         
         //read headers
         string headers = util.getline(in);
