@@ -17,7 +17,6 @@ class KruskalWallisCommand : public Command {
 public:
 	    
 	KruskalWallisCommand(string);	
-	KruskalWallisCommand();
 	~KruskalWallisCommand(){}
 	
 	vector<string> setParameters();
@@ -42,7 +41,7 @@ public:
     
 private:
     bool abort, allLines;
-    string outputDir, sharedfile, designfile, mclass;
+    string  sharedfile, designfile, mclass;
     vector<string> outputNames;
     set<string> labels;
     
