@@ -34,11 +34,13 @@ class ListSeqsCommand : public Command {
 	
 	private:
 		vector<string> outputNames;
-		vector<string> fastafiles, namefiles, groupfiles, countfiles, alignfiles, listfiles, taxfiles, fastqfiles, contigsreportfiles;
+		vector<string> fastafiles, namefiles, groupfiles, countfiles, alignfiles, listfiles, taxfiles, fastqfiles, contigsreportfiles, qualityfiles;
         string  format, inputFileName;
         bool abort;
         
-        void process(vector<string> files, set<string>&, void f(set<string>&, ifstream&, MothurOut*&));
+        void process(vector<string> files, unordered_set<string>&);
+        void process(vector<string> files, unordered_set<string>&, void f(unordered_set<string>&, ifstream&, MothurOut*&));
+
 };
 
 #endif
