@@ -12,6 +12,9 @@
 
 #include "command.hpp"
 #include "inputdata.h"
+#include "picrust.hpp"
+#include "biomsimple.hpp"
+#include "biomhdf5.hpp"
 
 
 class MakeBiomCommand : public Command {
@@ -34,23 +37,18 @@ public:
 	
 private:
     
-	string sharedfile, relabundfile, contaxonomyfile, metadatafile, groups,  format, label, referenceTax, picrustOtuFile, inputFileName, fileFormat;
-	vector<string> outputNames, Groups, sampleMetadata;
+	string sharedfile, relabundfile, contaxonomyfile, metadatafile, groups,  format, label, referenceTax, picrustOtuFile, inputFileName, fileFormat, output;
+	vector<string> outputNames, Groups;
 	set<string> labels;
     
 	bool abort, allLines, picrust;
     
-    int getBiom(SharedRAbundVectors*&);
-    int getBiom(SharedRAbundFloatVectors*&);
-    vector<string> getMetaData(SharedRAbundVectors*&);
-    vector<string> getMetaData(SharedRAbundFloatVectors*&);
-    vector<string> parseTax(string tax, vector<string>& scores);
-    int getSampleMetaData(SharedRAbundVectors*&);
-    int getSampleMetaData(SharedRAbundFloatVectors*&);
-    //for picrust
-    int getGreenGenesOTUIDs(SharedRAbundVectors*&, map<string, string>&);
-    int getGreenGenesOTUIDs(SharedRAbundFloatVectors*&, map<string, string>&);
-    map<string, string> readGGOtuMap();
+    void getBiom(SharedRAbundVectors*&, Picrust*, vector<Taxonomy>, vector<string>);
+    void getBiom(SharedRAbundFloatVectors*&, Picrust*, vector<Taxonomy>, vector<string>);
+     
+    vector<string> getSampleMetaData(SharedRAbundVectors*&);
+    vector<string> getSampleMetaData(SharedRAbundFloatVectors*&);
+    
 };
 
 
