@@ -18,7 +18,6 @@ class MakeFastQCommand : public Command {
 public:
 	
 	MakeFastQCommand(string);	
-	MakeFastQCommand();
 	~MakeFastQCommand(){}
 	
 	vector<string> setParameters();
@@ -37,7 +36,7 @@ public:
 	
 private:
 	
-	string fastafile, qualfile, outputDir, format;
+	string fastafile, qualfile,  format;
 	bool abort;
 	vector<string> outputNames;
 	
