@@ -19,7 +19,6 @@ class PCOACommand : public Command {
 	
 public:
 	PCOACommand(string);	
-	PCOACommand();
 	~PCOACommand(){}
 	
 	vector<string> setParameters();
@@ -37,7 +36,7 @@ public:
 private:
 
 	bool abort, metric;
-	string phylipfile, filename, fbase, outputDir;
+	string phylipfile, filename, fbase;
 	vector<string> outputNames;
 	LinearAlgebra linearCalc;
 	
