@@ -20,7 +20,6 @@ class PhylotypeCommand : public Command {
 	
 public:
 	PhylotypeCommand(string);	
-	PhylotypeCommand();
 	~PhylotypeCommand(){}
 	
 	vector<string> setParameters();
@@ -37,7 +36,7 @@ public:
 	
 private:
 	bool abort, allLines;
-	string taxonomyFileName, label, outputDir, namefile, countfile;
+	string taxonomyFileName, label,  namefile, countfile;
 	set<string> labels; //holds labels to be used
 	int cutoff;
 	map<string, string> namemap;
