@@ -107,7 +107,7 @@ string SffInfoCommand::getOutputPattern(string type) {
     }
 }
 //*******************************************************************************
-SffInfoCommand::SffInfoCommand(string option)  {
+SffInfoCommand::SffInfoCommand(string option) : Command()  {
 	try {
 
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -121,7 +121,7 @@ SffInfoCommand::SffInfoCommand(string option)  {
 			ValidParameters validParameter;
 			
             
-            string inputDir = validParameter.valid(parameters, "inputdir");
+            string inputDir = validParameter.validPath(parameters, "inputdir");
             if (inputDir == "not found"){    inputDir = "";        }
 
             sffFilename = validParameter.validFile(parameters, "sff");
@@ -218,7 +218,7 @@ int SffInfoCommand::execute(){
 	
         if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	} return 0; }
         
-        long start = time(NULL);
+        long start = time(nullptr);
         
         sffFilename = util.getFullPathName(sffFilename);
         m->mothurOut("Extracting info from " + sffFilename + " ...\n" );
@@ -229,7 +229,7 @@ int SffInfoCommand::execute(){
         
         int numReads = extractSffInfo(sffFilename, accnosName, oligos);
         
-        m->mothurOut("It took " + toString(time(NULL) - start) + " secs to extract " + toString(numReads) + ".\n");
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " secs to extract " + toString(numReads) + ".\n");
 		
 		if (sfftxtFilename != "") {  parseSffTxt(); }
 		
@@ -274,7 +274,7 @@ int SffInfoCommand::extractSffInfo(string input, string accnos, string oligos){
         if (accnos != "")	{  seqNames.clear(); seqNames = util.readAccnos(accnos);    }
 		else				{	seqNames.clear();		}
         
-        TrimOligos* trimOligos = NULL; TrimOligos* rtrimOligos = NULL;
+        TrimOligos* trimOligos = nullptr; TrimOligos* rtrimOligos = nullptr;
         if (hasOligos)   {
             readOligos(oligos);    split = 2;
             if (m->getControl_pressed()) { delete oligosObject; return 0; }
@@ -343,7 +343,7 @@ int SffInfoCommand::extractSffInfo(string input, string accnos, string oligos){
             delete read;
             
 			//report progress
-			if((count+1) % 10000 == 0){	m->mothurOut(toString(count+1)+"\n"); 		}
+			if((count+1) % 10000 == 0){	m->mothurOutJustToScreen(toString(count+1)+"\n"); 		}
 		
 			if (m->getControl_pressed()) { count = 0; break;   }
 			
@@ -353,7 +353,7 @@ int SffInfoCommand::extractSffInfo(string input, string accnos, string oligos){
 		}
 		
 		//report progress
-		if (!m->getControl_pressed()) {   if((count) % 10000 != 0){	m->mothurOut(toString(count)+"\n"); 	}  }
+		if (!m->getControl_pressed()) {   if((count) % 10000 != 0){	m->mothurOutJustToScreen(toString(count)+"\n"); 	}  }
 		
 		in.close();
 		
@@ -467,7 +467,7 @@ int SffInfoCommand::adjustCommonHeader(SffCommonHeader*& header){
 void SffInfoCommand::assignToSample(SffRead*& read, TrimOligos*& trimOligos, TrimOligos*& rtrimOligos){
     try {
         
-        int barcodeIndex, primerIndex, trashCodeLength;
+        int barcodeIndex, primerIndex, trashCodeLength; trashCodeLength = 0; primerIndex = 0; barcodeIndex = 0;
         
         if (hasOligos)      {  trashCodeLength = findGroup(read, barcodeIndex, primerIndex, trimOligos, rtrimOligos);                }
         else if (hasGroup)  {  trashCodeLength = findGroup(read, barcodeIndex, primerIndex, "groupMode");   }
@@ -668,7 +668,7 @@ int SffInfoCommand::parseSffTxt() {
 		string flowgramCode = util.getline(inSFF);
 		string flowChars = util.getline(inSFF);
 		string keySequence = util.getline(inSFF);
-		util.gobble(inSFF);
+		gobble(inSFF);
 		
 		string seqName;
 		
@@ -684,18 +684,18 @@ int SffInfoCommand::parseSffTxt() {
 			//parse read header
 			inSFF >> seqName;
 			seqName = seqName.substr(1);
-			util.gobble(inSFF);
+			gobble(inSFF);
 			read.setName(seqName);
 			
 			string runPrefix = parseHeaderLineToString(inSFF);		read.setTimeStamp(runPrefix);
 			string regionNumber = parseHeaderLineToString(inSFF);	read.setRegion(regionNumber);
 			string xyLocation = parseHeaderLineToString(inSFF);		read.setXY(xyLocation);
-			util.gobble(inSFF);
+			gobble(inSFF);
 				
 			string runName = parseHeaderLineToString(inSFF);
 			string analysisName = parseHeaderLineToString(inSFF);
 			string fullPath = parseHeaderLineToString(inSFF);
-			util.gobble(inSFF);
+			gobble(inSFF);
 			
             unsigned short readHeaderLen = parseHeaderLineToShort(inSFF); read.setHeaderLength(readHeaderLen);
             unsigned short nameLength = parseHeaderLineToShort(inSFF); read.setNameLength(nameLength);
@@ -704,7 +704,7 @@ int SffInfoCommand::parseSffTxt() {
 			unsigned short clipQualRight = parseHeaderLineToShort(inSFF); read.setClipQualRight(clipQualRight);
             unsigned short clipAdapLeft = parseHeaderLineToShort(inSFF); read.setClipAdapterLeft(clipAdapLeft);
             unsigned short clipAdapRight = parseHeaderLineToShort(inSFF); read.setClipAdapterRight(clipAdapRight);
-			util.gobble(inSFF);
+			gobble(inSFF);
 				
 			//parse read
             vector<unsigned short> flowVector = parseHeaderLineToFloatVector(inSFF, numFlows);	read.setFlowgrams(flowVector);
@@ -717,7 +717,7 @@ int SffInfoCommand::parseSffTxt() {
 			
 			string bases = parseHeaderLineToString(inSFF); read.setBases(bases);
 			vector<unsigned int> qualityScores = parseHeaderLineToIntVector(inSFF, numBases); read.setQualScores(qualityScores);
-			util.gobble(inSFF);
+			gobble(inSFF);
 					
 			//if you have provided an accosfile and this seq is not in it, then dont print
 			bool print = true;
@@ -755,13 +755,13 @@ int SffInfoCommand::parseSffTxt() {
 //*****************************************************************************
 int SffInfoCommand::parseHeaderLineToInt(ifstream& file){
 	try {
-		int number;
+		int number = 0;
 		
 		while (!file.eof())	{
 			char c = file.get(); 
 			if (c == ':'){ file >> number; break; }
 		}
-		util.gobble(file);
+		gobble(file);
 		return number;
 	}
 	catch(exception& e) {
@@ -780,7 +780,7 @@ unsigned short SffInfoCommand::parseHeaderLineToShort(ifstream& file){
             
             if (c == ':'){ file >> text; break; }
         }
-        util.gobble(file);
+        gobble(file);
         
         unsigned short value;
         util.mothurConvert(text, value);
@@ -801,7 +801,7 @@ string SffInfoCommand::parseHeaderLineToString(ifstream& file){
 			
 			if (c == ':'){ file >> text; break; }
 		}
-		util.gobble(file);
+		gobble(file);
 		
 		return text;
 	}
@@ -823,7 +823,7 @@ vector<unsigned short> SffInfoCommand::parseHeaderLineToFloatVector(ifstream& fi
 				break;
 			}
 		}
-		util.gobble(file);	
+		gobble(file);	
 		return floatVector;
 	}
 	catch(exception& e) {
@@ -844,7 +844,7 @@ vector<unsigned int> SffInfoCommand::parseHeaderLineToIntVector(ifstream& file,
 				break;
 			}
 		}
-		util.gobble(file);	
+		gobble(file);	
 		return intVector;
 	}
 	catch(exception& e) {
