@@ -49,7 +49,7 @@ vector<string> SplitAbundCommand::setParameters(){
 string SplitAbundCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The split.abund command reads a fasta file or a list or a names file splits the sequences into rare and abundant groups. \n";
+		helpString += "The split.abund command reads a fasta file or a list or a names or a count file splits the sequences into rare and abundant groups. \n";
 		helpString += "The split.abund command parameters are fasta, list, name, count, cutoff, group, label and cutoff.\n";
 		helpString += "The fasta or a list or name or count parameter are required, and you must provide a cutoff value.\n";
 		helpString += "The cutoff parameter is used to qualify what is abundant and rare. If cutoff < 1, mothur assumes this is a percentage. 0.02 -> rare reads represent <= 2% of total reads. \n";
@@ -89,7 +89,7 @@ string SplitAbundCommand::getOutputPattern(string type) {
 }
 
 //**********************************************************************************************************************
-SplitAbundCommand::SplitAbundCommand(string option)  {
+SplitAbundCommand::SplitAbundCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -256,7 +256,7 @@ int SplitAbundCommand::splitList() {
         
         if (m->getControl_pressed()) { delete list; return 0; }
         
-        while (list != NULL) {
+        while (list != nullptr) {
             
             if (m->getControl_pressed()) { delete list; break; }
             
@@ -568,14 +568,13 @@ int SplitAbundCommand::splitNames() { //namefile
         }
 			
 		//open input file
-		ifstream in;
-		util.openInputFile(namefile, in);
+		ifstream in; util.openInputFile(namefile, in);
 		
 		while (!in.eof()) {
 			if (m->getControl_pressed()) { break; }
 			
 			string firstCol, secondCol;
-            in >> firstCol; util.gobble(in); in >> secondCol; util.gobble(in);
+            in >> firstCol; gobble(in); in >> secondCol; gobble(in);
 			
 			int size = util.getNumNames(secondCol);
 				
