@@ -10,6 +10,7 @@
 #include "splitgroupscommand.h"
 #include "sequenceparser.h"
 #include "counttable.h"
+#include "inputdata.h"
 
 //**********************************************************************************************************************
 vector<string> SplitGroupCommand::setParameters(){	
@@ -90,9 +91,41 @@ string SplitGroupCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-
 //**********************************************************************************************************************
-SplitGroupCommand::SplitGroupCommand(string option)  {
+
+SplitGroupCommand::SplitGroupCommand(vector<string> g, string ffile, string count, string outd) : Command() {
+    try {
+        abort = false; calledHelp = false;
+        vector<string> tempOutNames;
+        outputTypes["count"] = tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        
+        Groups = g; groupfile = ""; namefile = "";
+        fastafile = ffile; countfile = count; outputdir = outd;
+        string temp = current->getProcessors(); processors = current->setProcessors(temp);
+        
+        if (processors > Groups.size()) { processors = Groups.size(); m->mothurOut("Reducing processors to " + toString(Groups.size()) + ".\n"); }
+        
+        //divide the groups between the processors
+        int remainingPairs = Groups.size();
+        int startIndex = 0;
+        for (int remainingProcessors = processors; remainingProcessors > 0; remainingProcessors--) {
+          int numPairs = remainingPairs; //case for last processor
+          if (remainingProcessors != 1) { numPairs = ceil(remainingPairs / remainingProcessors); }
+          lines.push_back(linePair(startIndex, (startIndex+numPairs))); //startIndex, endIndex
+          startIndex = startIndex + numPairs;
+          remainingPairs = remainingPairs - numPairs;
+        }
+        
+        splitFastaCount();
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SplitGroupCommand", "SplitGroupCommand - mothurRun");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+SplitGroupCommand::SplitGroupCommand(string option) : Command()  {
 	try {
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
@@ -202,14 +235,6 @@ SplitGroupCommand::SplitGroupCommand(string option)  {
                 else { outputdir = util.hasPath(countfile);  }
             }
 			
-            if (countfile == "") {
-                if (namefile == "") {
-                    vector<string> files;
-                    if (fastafile != "")    {  files.push_back(fastafile);  }
-                    else                    {  files.push_back(flowfile);   }
-                    if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
-                }
-            }
 		}
 
 	}
@@ -297,8 +322,7 @@ int driverRunNameGroup(splitGroups2Struct* params){
 	try {
 		if (params->m->getControl_pressed()) { return 0; }
         
-        GroupMap groupMap;
-        groupMap.readMap(params->groupfile, params->Groups);
+        GroupMap groupMap; groupMap.readMap(params->groupfile, params->Groups);
 		vector<string> namesGroups = groupMap.getNamesOfGroups();
         if (params->Groups.size() == 0) { params->Groups = namesGroups; }
 		
@@ -312,29 +336,24 @@ int driverRunNameGroup(splitGroups2Struct* params){
             else { params->m->mothurOut("[ERROR]: Can find group " + params->Groups[i] + ", quitting.\n"); params->m->setControl_pressed(true); break; }
 			
 			params->m->mothurOut("Processing group: " + params->Groups[i] + "\n");
-			
-			string newFasta = files[0];
-            string newList = files[1];
-            string newGroup = files[2];
-			string newName = files[3];
             
             vector<string> namesSeqsInThisGroup = groupMap.getNamesSeqs(params->Groups[i]);
             ofstream outGroup, outAccnos;
-            params->util.openOutputFile(newGroup, outGroup);
-            params->util.openOutputFile(newGroup+".accnos", outAccnos);
+            params->util.openOutputFile(files[2], outGroup);
+            params->util.openOutputFile(files[2]+".accnos", outAccnos);
             for (long long j = 0; j < namesSeqsInThisGroup.size(); j++) {
                 outGroup << namesSeqsInThisGroup[j] << '\t' << params->Groups[i] << endl;
                 outAccnos << namesSeqsInThisGroup[j] << endl;
             }
             outGroup.close(); outAccnos.close();
-            params->outputNames.push_back(newGroup); params->outputTypes["group"].push_back(newGroup);
+            params->outputNames.push_back(files[2]); params->outputTypes["group"].push_back(files[2]);
             
             //use unique.seqs to create new name and fastafile
             string uniqueFasta = params->fastafile+params->Groups[i];
             string uniqueName = params->namefile+params->Groups[i];
             string uniqueList = params->listfile+params->Groups[i];
             
-            string inputString = "dups=f, accnos=" + newGroup+".accnos";
+            string inputString = "dups=f, accnos=" + files[2]+".accnos";
             if (params->namefile != "") {
                 inputString += ", name=" + uniqueName;
                 params->util.copyFile(params->namefile, uniqueName);
@@ -357,23 +376,23 @@ int driverRunNameGroup(splitGroups2Struct* params){
             delete getCommand;
             
             if (params->fastafile != "") {
-                params->util.renameFile(filenames["fasta"][0], newFasta);
-                params->outputNames.push_back(newFasta); params->outputTypes["fasta"].push_back(newFasta);
+                params->util.renameFile(filenames["fasta"][0], files[0]);
+                params->outputNames.push_back(files[0]); params->outputTypes["fasta"].push_back(files[0]);
                 params->util.mothurRemove(uniqueFasta);
             }
             if (params->listfile != "") {
-                params->util.renameFile(filenames["list"][0], newList);
-                params->outputNames.push_back(newList); params->outputTypes["list"].push_back(newList);
+                params->util.renameFile(filenames["list"][0], files[1]);
+                params->outputNames.push_back(files[1]); params->outputTypes["list"].push_back(files[1]);
                 params->util.mothurRemove(uniqueList);
             }
             if (params->namefile != "") {
-                params->util.renameFile(filenames["name"][0], newName);
-                params->outputNames.push_back(newName); params->outputTypes["name"].push_back(newName);
+                params->util.renameFile(filenames["name"][0], files[3]);
+                params->outputNames.push_back(files[3]); params->outputTypes["name"].push_back(files[3]);
             }
             
             params->m->mothurOut("/******************************************/\nDone.\n");
             
-            params->util.mothurRemove(newGroup+".accnos");
+            params->util.mothurRemove(files[2]+".accnos");
             params->util.mothurRemove(uniqueName);
 			
 			if (params->m->getControl_pressed()) {  for (int i = 0; i < params->outputNames.size(); i++) {	params->util.mothurRemove(params->outputNames[i]);	} return 0; }
@@ -389,13 +408,36 @@ int driverRunNameGroup(splitGroups2Struct* params){
 //**********************************************************************************************************************
 int driverRunCount(splitGroups2Struct* params){
     try {
-        CountTable ct;
-        ct.readTable(params->countfile, true, false, params->Groups);
+        CountTable ct; ct.readTable(params->countfile, true, false, params->Groups);
         if (!ct.hasGroupInfo()) { params->m->mothurOut("[ERROR]: your count file does not contain group info, cannot split by group.\n"); params->m->setControl_pressed(true); }
         
         if (params->m->getControl_pressed()) { return 0; }
         
         params->Groups = ct.getNamesOfGroups();
+        
+        vector<string> listFileOutputNames;
+        if (params->listfile != "") { //create output file names
+            InputData input(params->listfile, "list", nullVector);
+            ListVector* list = input.getListVector();
+            
+            vector<string> files;
+            map<string, vector<string> >::iterator it = params->group2Files.find(params->Groups[0]);
+            
+            if (it != params->group2Files.end()) { files = it->second; }
+            else { params->m->mothurOut("[ERROR]: Can find group " + params->Groups[0] + ", quitting.\n"); params->m->setControl_pressed(true);  }
+
+            string listFileRoot = params->outputDir + params->util.getRootName(params->util.getSimpleName(files[1]));
+            string listExt = params->util.getExtension(files[1]);
+
+            while(list != nullptr) {
+                                
+                listFileOutputNames.push_back(listFileRoot + list->getLabel() + listExt);
+
+                delete list;
+                list = input.getListVector();
+            }
+        }
+        
         //GroupName -> files(fasta, list, count)
         for (int i = 0; i < params->Groups.size(); i++) { //Groups only contains the samples assigned to this process
            
@@ -405,61 +447,117 @@ int driverRunCount(splitGroups2Struct* params){
             if (it != params->group2Files.end()) { files = it->second; }
             else { params->m->mothurOut("[ERROR]: Can find group " + params->Groups[i] + ", quitting.\n"); params->m->setControl_pressed(true); break; }
             
+            //print new count file
             string newCountFile = files[2];
             vector<string> tempGroups; tempGroups.push_back(params->Groups[i]);
             ct.printCompressedTable(newCountFile, tempGroups);
             params->outputNames.push_back(newCountFile); params->outputTypes["count"].push_back(newCountFile);
             vector<string> namesOfSeqsInGroup = ct.getNamesOfSeqs(params->Groups[i]);
+            unordered_set<string> thisGroupsNames = params->util.mothurConvert(namesOfSeqsInGroup);
             
-            ofstream outAccnos;
-            params->util.openOutputFile(newCountFile+".accnos", outAccnos);
-            for (long long j = 0; j < namesOfSeqsInGroup.size(); j++) { outAccnos << namesOfSeqsInGroup[j] << endl; }
-            outAccnos.close();
-            
-            //use unique.seqs to create new name and fastafile
-            string uniqueFasta = params->fastafile+params->Groups[i];
-            string uniqueList = params->listfile+params->Groups[i];
-            
-            string inputString = "dups=f, accnos=" + newCountFile +".accnos";
-            if (params->fastafile != "") {
-                inputString += ", fasta=" + uniqueFasta;
-                params->util.copyFile(params->fastafile, uniqueFasta);
-            }
-            if (params->listfile != "")  {
-                inputString += ", list=" + uniqueList;
-                params->util.copyFile(params->listfile, uniqueList);
-            }
+            //If more than one distance, use vector of list file outputs
+            pair<string, string> fastaFilePair(params->fastafile, files[0]);
+            pair<string, vector<string> > listFilePair(params->listfile, listFileOutputNames);
             
             params->m->mothurOut("/******************************************/\n");
-            params->m->mothurOut("Running command: get.seqs(" + inputString + ")\n");
-            
-            GetSeqsCommand getCommand(inputString);
-            getCommand.execute();
-            
-            map<string, vector<string> > filenames = getCommand.getOutputFiles();
-            
-            if (params->fastafile != "") {
-                params->util.renameFile(filenames["fasta"][0], files[0]);
-                params->outputNames.push_back(files[0]); params->outputTypes["fasta"].push_back(files[0]);
-                params->util.mothurRemove(uniqueFasta);
-            }
-            if (params->listfile != "") {
-                params->util.renameFile(filenames["list"][0], files[1]);
-                params->outputNames.push_back(files[1]); params->outputTypes["list"].push_back(files[1]);
-                params->util.mothurRemove(uniqueList);
-            }
+            params->m->mothurOut("Selecting sequences for group " + params->Groups[i] + "\n\n");
         
-            params->m->mothurOut("/******************************************/\nDone.\n");
+            Command* getCommand = new GetSeqsCommand(thisGroupsNames, fastaFilePair, listFilePair, nullStringPair, "");
             
-            params->util.mothurRemove(newCountFile+".accnos");
+            delete getCommand;
+        
+            if (params->listfile != "") { params->outputNames.insert(params->outputNames.end(), listFileOutputNames.begin(), listFileOutputNames.end()); params->outputTypes["list"].insert(params->outputNames.end(), listFileOutputNames.begin(), listFileOutputNames.end()); }
+        
+            params->m->mothurOut("/******************************************/\n\n");
+
+            if (params->fastafile != "") { params->outputNames.push_back(files[0]); params->outputTypes["fasta"].push_back(files[0]); }
             
-            if (params->m->getControl_pressed()) {  for (int i = 0; i < params->outputNames.size(); i++) {	params->util.mothurRemove(params->outputNames[i]);	} return 0; }
+            if (params->m->getControl_pressed()) {  for (int i = 0; i < params->outputNames.size(); i++) {	params->util.mothurRemove(params->outputNames[i]);	} break; }
         }
-        
+           
         return 0;
     }
     catch(exception& e) {
-        params->m->errorOut(e, "SplitGroupCommand", "runCount");
+        params->m->errorOut(e, "SplitGroupCommand", "driverRunCount");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+
+//assumes nameToGroup[seq1] -> 1,3 means seq1 should be written to outputFiles[1] and outputFiles[3]
+       
+int driverFastaCount(splitGroups3Struct* params){
+    try {
+        CountTable ct; ct.readTable(params->countfile, true, false, params->Groups);
+        if (!ct.hasGroupInfo()) { params->m->mothurOut("[ERROR]: your count file does not contain group info, cannot split by group.\n"); params->m->setControl_pressed(true); }
+        
+        if (params->m->getControl_pressed()) { return 0; }
+        
+        params->Groups = ct.getNamesOfGroups();
+        int numGroups = params->Groups.size();
+        
+        for (int i = 0; i < numGroups; i++) { //Groups only contains the samples assigned to this process
+           
+            vector<string> outputFastaFiles; string g = ""; int count = 0;
+            unordered_map<string, vector<int> > nameToGroup; unordered_map<string, vector<int> >::iterator it;
+            string groupNameOutput = ""; vector<string> groups;
+            
+            while ((count < params->splitNum) && (i < numGroups) ){
+            
+                //print new count file
+                string newCountFile = params->fileRootExts[2] + params->Groups[i] + params->fileRootExts[3];
+                vector<string> tempGroups; tempGroups.push_back(params->Groups[i]);
+                ct.printCompressedTable(newCountFile, tempGroups);
+                params->outputNames.push_back(newCountFile); params->outputTypes["count"].push_back(newCountFile);
+                
+                vector<string> namesOfSeqsInGroup = ct.getNamesOfSeqs(params->Groups[i]);
+            
+                string newFasta = params->fileRootExts[0] + params->Groups[i] + params->fileRootExts[1];
+                outputFastaFiles.push_back(newFasta);
+                
+                for (string name : namesOfSeqsInGroup) {
+                    it = nameToGroup.find(name);
+                    
+                    if (it != nameToGroup.end()) {
+                        (it->second).push_back(count);
+                    }else {
+                        vector<int> thisSeqsGroups; thisSeqsGroups.push_back(count);
+                        nameToGroup[name] = thisSeqsGroups;
+                    }
+                }
+            
+                groups.push_back(params->Groups[i]);
+                
+                groupNameOutput += params->Groups[i] + "-";
+                
+                count++; i++;
+            }
+            
+            i--;
+            
+            if (groupNameOutput.length() != 0) { groupNameOutput = groupNameOutput.substr(0, groupNameOutput.length()-1); }
+                
+            params->m->mothurOut("\nSelecting sequences for groups " + groupNameOutput + "\n\n");
+        
+            Command* getCommand = new GetSeqsCommand(nameToGroup, params->fastafile, outputFastaFiles, groups);
+        
+            map<string, vector<string> > fileOutputs = getCommand->getOutputFiles();
+            
+            delete getCommand;
+            
+            map<string, vector<string> >::iterator itOut = fileOutputs.find("fasta");
+            if (itOut != fileOutputs.end()) {
+                vector<string> o = itOut->second;
+                for (string name : o) { params->outputNames.push_back(name); params->outputTypes["fasta"].push_back(name);  }
+            }
+
+            if (params->m->getControl_pressed()) {  for (int i = 0; i < params->outputNames.size(); i++) {    params->util.mothurRemove(params->outputNames[i]);    } break; }
+        }
+           
+        return 0;
+    }
+    catch(exception& e) {
+        params->m->errorOut(e, "SplitGroupCommand", "driverRunCount");
         exit(1);
     }
 }
@@ -515,10 +613,54 @@ void SplitGroupCommand::splitCountOrGroup(bool isCount){
     }
 }
 //**********************************************************************************************************************
+//splitGroups3Struct(string count, string fasta, string outd, vector<string> g, int st, int en) : countfile(count), start(st), end(en)
+void SplitGroupCommand::splitFastaCount(){
+    try {
+        //create array of worker threads
+        vector<std::thread*> workerThreads;
+        vector<splitGroups3Struct*> data;
+
+        //Lauch worker threads
+        for (int i = 0; i < processors-1; i++) {
+            splitGroups3Struct* dataBundle = new splitGroups3Struct(countfile, fastafile, outputdir, Groups, lines[i+1].start, lines[i+1].end);
+            data.push_back(dataBundle);
+    
+            workerThreads.push_back(new std::thread(driverFastaCount, dataBundle));
+        }
+
+        splitGroups3Struct* dataBundle = new splitGroups3Struct(countfile, fastafile, outputdir, Groups, lines[0].start, lines[0].end);
+        
+        driverFastaCount(dataBundle);
+        
+        outputNames.insert(outputNames.end(), dataBundle->outputNames.begin(), dataBundle->outputNames.end());
+        for (itTypes = dataBundle->outputTypes.begin(); itTypes != dataBundle->outputTypes.end(); itTypes++) {
+            outputTypes[itTypes->first].insert(outputTypes[itTypes->first].end(), itTypes->second.begin(), itTypes->second.end());
+        }
+        
+        delete dataBundle;
+        
+        for (int i = 0; i < processors-1; i++) {
+            workerThreads[i]->join();
+
+            outputNames.insert(outputNames.end(), data[i]->outputNames.begin(), data[i]->outputNames.end());
+            for (itTypes = data[i]->outputTypes.begin(); itTypes != data[i]->outputTypes.end(); itTypes++) {
+                outputTypes[itTypes->first].insert(outputTypes[itTypes->first].end(), itTypes->second.begin(), itTypes->second.end());
+            }
+
+            delete data[i];
+            delete workerThreads[i];
+        }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SplitGroupCommand", "splitFastaCount");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
 int driverSplitFlow(splitGroupsStruct* params){
     try {
-        GroupMap* groupMap = NULL;
-        CountTable* ct = NULL;
+        GroupMap* groupMap = nullptr;
+        CountTable* ct = nullptr;
         vector<string> namesGroups;
         if (params->groupfile != "") {
             groupMap = new GroupMap(params->groupfile);
@@ -532,24 +674,24 @@ int driverSplitFlow(splitGroupsStruct* params){
         
         if (params->Groups.size() == 0) { params->Groups = namesGroups; }
         
-        if (params->m->getControl_pressed()) { if (groupMap != NULL) { delete groupMap; }else if (ct != NULL) { delete ct; } return 0; }
+        if (params->m->getControl_pressed()) { if (groupMap != nullptr) { delete groupMap; }else if (ct != nullptr) { delete ct; } return 0; }
         
         string name, flows;
         int count = 0;
         ifstream in; params->util.openInputFile(params->inputFileName, in);
-        in >> flows; params->util.gobble(in);
+        in >> flows; gobble(in);
         
         while (!in.eof()) {
             if (params->m->getControl_pressed()) { break; }
             
-            in >> name; params->util.gobble(in);
-            flows = params->util.getline(in); params->util.gobble(in);
+            in >> name; gobble(in);
+            flows = params->util.getline(in); gobble(in);
             
             vector<string> thisSeqsGroups;
-            if (groupMap != NULL) {
+            if (groupMap != nullptr) {
                 string thisGroup = groupMap->getGroup(name);
                 thisSeqsGroups.push_back(thisGroup);
-            }else if (ct != NULL) { thisSeqsGroups  = ct->getGroups(name); }
+            }else if (ct != nullptr) { if (ct->inTable(name)) { thisSeqsGroups  = ct->getGroups(name); } }
             
             for (int i = 0; i < thisSeqsGroups.size(); i++) {
                 
@@ -581,7 +723,7 @@ int driverSplitFlow(splitGroupsStruct* params){
             }
         }
         
-        if (params->m->getControl_pressed()) { if (groupMap != NULL) { delete groupMap; }else if (ct != NULL) { delete ct; } return 0; }
+        if (params->m->getControl_pressed()) { if (groupMap != nullptr) { delete groupMap; }else if (ct != nullptr) { delete ct; } return 0; }
         
         return count;
     }
@@ -594,8 +736,8 @@ int driverSplitFlow(splitGroupsStruct* params){
 //**********************************************************************************************************************
 int driverSplitFastq(splitGroupsStruct* params){
     try {
-        GroupMap* groupMap = NULL;
-        CountTable* ct = NULL;
+        GroupMap* groupMap = nullptr;
+        CountTable* ct = nullptr;
         vector<string> namesGroups;
         if (params->groupfile != "") {
             groupMap = new GroupMap(params->groupfile);
@@ -607,7 +749,7 @@ int driverSplitFastq(splitGroupsStruct* params){
             namesGroups = ct->getNamesOfGroups();
         }else { params->m->mothurOut("[ERROR]: you must provide a count or group file to split by group. quitting... \n"); params->m->setControl_pressed(true);  return 0; }
         
-        if (params->m->getControl_pressed()) { if (groupMap != NULL) { delete groupMap; }else if (ct != NULL) { delete ct; } return 0; }
+        if (params->m->getControl_pressed()) { if (groupMap != nullptr) { delete groupMap; }else if (ct != nullptr) { delete ct; } return 0; }
         
         int count = 0;
         ifstream in; params->util.openInputFile(params->inputFileName, in);
@@ -616,14 +758,14 @@ int driverSplitFastq(splitGroupsStruct* params){
             if (params->m->getControl_pressed()) { break; }
             
             bool ignore = false;
-            FastqRead thisRead(in, ignore, params->format); params->util.gobble(in);
+            FastqRead thisRead(in, ignore, params->format); gobble(in);
             string name = thisRead.getName();
             
             vector<string> thisSeqsGroups;
-            if (groupMap != NULL) {
+            if (groupMap != nullptr) {
                 string thisGroup = groupMap->getGroup(name);
                 thisSeqsGroups.push_back(thisGroup);
-            }else if (ct != NULL) { thisSeqsGroups  = ct->getGroups(name); }
+            }else if (ct != nullptr) { if (ct->inTable(name)) { thisSeqsGroups  = ct->getGroups(name); } }
             
             for (int i = 0; i < thisSeqsGroups.size(); i++) {
                 
@@ -658,7 +800,7 @@ int driverSplitFastq(splitGroupsStruct* params){
             }
         }
         
-        if (params->m->getControl_pressed()) { if (groupMap != NULL) { delete groupMap; }else if (ct != NULL) { delete ct; } return 0; }
+        if (params->m->getControl_pressed()) { if (groupMap != nullptr) { delete groupMap; }else if (ct != nullptr) { delete ct; } return 0; }
         
         return count;
         
@@ -707,7 +849,7 @@ void SplitGroupCommand::splitFastqOrFlow(string inputFile, string extension){
             workerThreads[i]->join();
 
             outputNames.insert(outputNames.end(), data[i]->outputNames.begin(), data[i]->outputNames.end());
-            for (itTypes = dataBundle->outputTypes.begin(); itTypes != dataBundle->outputTypes.end(); itTypes++) {
+            for (itTypes = data[i]->outputTypes.begin(); itTypes != data[i]->outputTypes.end(); itTypes++) {
                 outputTypes[itTypes->first].insert(outputTypes[itTypes->first].end(), itTypes->second.begin(), itTypes->second.end());
             }
 
