@@ -10,7 +10,6 @@
 #include "alignmentdb.h"
 #include "kmerdb.hpp"
 #include "suffixdb.hpp"
-#include "blastdb.hpp"
 
 /**************************************************************************************************/
 AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gapOpen, float gapExtend, float match, float misMatch, int tid, bool writeShortcut){		//	This assumes that the template database is in fasta format, may
@@ -23,16 +22,15 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
 		threadID = tid;
 		Utils util;
         
-        long start = time(NULL);
+        long start = time(nullptr);
         m->mothurOut("\nReading in the " + fastaFileName + " template sequences...\t");	cout.flush();
         //bool aligned = false;
         int tempLength = 0;
         
-        ifstream fastaFile;
-        util.openInputFile(fastaFileName, fastaFile);
+        ifstream fastaFile; util.openInputFile(fastaFileName, fastaFile);
         
         while (!fastaFile.eof()) {
-            Sequence temp(fastaFile);  util.gobble(fastaFile);
+            Sequence temp(fastaFile);  gobble(fastaFile);
             
             if (m->getControl_pressed()) {  templateSequences.clear(); break;  }
             
@@ -54,7 +52,7 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
         
         m->mothurOut("DONE.\n");
         cout.flush();
-        m->mothurOut("It took " + toString(time(NULL) - start) + " to read  " + toString(templateSequences.size()) + " sequences.\n");   
+        m->mothurOut("It took " + toString(time(nullptr) - start) + " to read  " + toString(templateSequences.size()) + " sequences.\n");   
 
 		
 		//in case you delete the seqs and then ask for them
@@ -86,8 +84,7 @@ AlignmentDB::AlignmentDB(string fastaFileName, string s, int kmerSize, float gap
 			
 		}
 		else if(method == "suffix")		{	search = new SuffixDB(numSeqs);								}
-		else if(method == "blast")		{	search = new BlastDB(fastaFileName.substr(0,fastaFileName.find_last_of(".")+1), gapOpen, gapExtend, match, misMatch, "", threadID);	}
-		else {
+        else {
 			method = "kmer";
 			m->mothurOut(method + " is not a valid search option. I will run the command using kmer, ksize=8.\n");
 			search = new KmerDB(fastaFileName, 8);
@@ -127,7 +124,6 @@ AlignmentDB::AlignmentDB(string s){
 		method = s;
 		
 		if(method == "suffix")		{	search = new SuffixDB();	}
-		else if(method == "blast")	{	search = new BlastDB("", 0);		}
 		else						{	search = new KmerDB();		}
 
 				
