@@ -17,11 +17,12 @@
 
 //Data Structure for a fasta file.
 
-#include "mothur.h"
 #include "mothurout.h"
 #include "utils.hpp"
 #include "writer.h"
 
+class Protein;
+
 /**************************************************************************************************/
 
 class Sequence {
@@ -41,7 +42,7 @@ public:
     #ifdef USE_BOOST
     Sequence(boost::iostreams::filtering_istream&);
     #endif
-    ~Sequence() {}
+    ~Sequence() = default;
 	
 	void setName(string);
     string getName();
@@ -53,6 +54,9 @@ public:
     string getComment();
 	void setPairwise(string);
 	string getPairwise();
+    Protein getProtein(int, bool); //starting frame, trim
+    Protein getProtein(); //assumes starting frame 1, trim=false
+    bool isAligned();
 	
 	string getInlineSeq();
     int getNumNs();
@@ -75,6 +79,7 @@ public:
 	void printSequence(ostream&);
     void printSequence(OutputWriter*);
     void printUnAlignedSequence(ostream&);
+    
 	
 protected:
     
