@@ -96,8 +96,8 @@ private:
     double mean;
 
 public:
-    MeanAndStd() {}
-    ~MeanAndStd() {}
+    MeanAndStd() = default;
+    ~MeanAndStd() = default;
 
     void initialize() {
         n = 0.0;
@@ -980,7 +980,7 @@ double OneVsOneMultiClassSvmTrainer::trainOnKFolds(SmoTrainer& smoTrainer, Kerne
 class UnrankedFeature {
 public:
     UnrankedFeature(const Feature& f) : feature(f), rankingCriterion(0.0) {}
-    ~UnrankedFeature() {}
+    ~UnrankedFeature() = default;
 
     Feature getFeature() const { return feature; }
 
@@ -1038,7 +1038,7 @@ RankedFeatureList SvmRfe::getOrderedFeatureList(SvmDataset& svmDataset, OneVsOne
 
         m->mothurOut( "two-class SVM performance" ); m->mothurOutEndLine();
 
-        m->mothurOut("class 1\tclass 2\tprecision\trecall\f\accuracy"); m->mothurOutEndLine();
+        m->mothurOut("class 1\tclass 2\tprecision\trecall\f\accuracy\n"); 
         for ( SvmVector::const_iterator svm = s->getSvmList().begin(); svm != s->getSvmList().end(); svm++ ) {
             SvmPerformanceSummary sps = s->getSvmPerformanceSummary(**svm);
             m->mothurOut(toString(sps.getPositiveClassLabel())
@@ -1077,7 +1077,7 @@ RankedFeatureList SvmRfe::getOrderedFeatureList(SvmDataset& svmDataset, OneVsOne
         // eliminate the bottom 1/3 features - fast but results slightly different from above
         // how about 1/4?
         int eliminateFeatureCount = ceil(unrankedFeatureList.size() / 4.0);
-        m->mothurOut( "eliminating " + toString(eliminateFeatureCount) + " feature(s) of " + toString(unrankedFeatureList.size()) + " total features"); m->mothurOutEndLine();
+        m->mothurOut( "eliminating " + toString(eliminateFeatureCount) + " feature(s) of " + toString(unrankedFeatureList.size()) + " total features\n"); 
         m->mothurOutEndLine();
         UnrankedFeatureList featuresToEliminate;
         for ( int i = 0; i < eliminateFeatureCount; i++ ) {
